Index: trunk/src/org/openstreetmap/josm/plugins/PluginInformation.java
===================================================================
--- trunk/src/org/openstreetmap/josm/plugins/PluginInformation.java	(revision 5029)
+++ trunk/src/org/openstreetmap/josm/plugins/PluginInformation.java	(revision 5121)
@@ -5,4 +5,5 @@
 
 import java.awt.Image;
+import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.FileInputStream;
@@ -55,4 +56,6 @@
     public List<URL> libraries = new LinkedList<URL>();
     public final Map<String, String> attr = new TreeMap<String, String>();
+    
+    private static final ImageIcon emptyIcon = new ImageIcon(new BufferedImage(24, 24, BufferedImage.TYPE_INT_ARGB));
 
     /**
@@ -447,5 +450,5 @@
     public ImageIcon getScaledIcon() {
         if (icon == null)
-            return null;
+            return emptyIcon;
         return new ImageIcon(icon.getImage().getScaledInstance(24, 24, Image.SCALE_SMOOTH));
     }

Index: trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java
===================================================================
--- trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 5029)
+++ trunk/src/org/openstreetmap/josm/plugins/PluginHandler.java	(revision 5121)
@@ -6,9 +6,9 @@
 import static org.openstreetmap.josm.tools.I18n.trn;
 
+import java.awt.Component;
 import java.awt.Font;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
-import java.awt.Window;
 import java.awt.event.ActionEvent;
 import java.io.File;
@@ -175,7 +175,8 @@
      * Also notifies the user about removed deprecated plugins
      *
+     * @param parent The parent Component used to display warning popup
      * @param plugins the collection of plugins
      */
-    private static void filterDeprecatedPlugins(Window parent, Collection<String> plugins) {
+    private static void filterDeprecatedPlugins(Component parent, Collection<String> plugins) {
         Set<DeprecatedPlugin> removedPlugins = new TreeSet<DeprecatedPlugin>();
         for (DeprecatedPlugin depr : DEPRECATED_PLUGINS) {
@@ -226,5 +227,5 @@
      * @param plugins the collection of plugins
      */
-    private static void filterUnmaintainedPlugins(Window parent, Collection<String> plugins) {
+    private static void filterUnmaintainedPlugins(Component parent, Collection<String> plugins) {
         for (String unmaintained : UNMAINTAINED_PLUGINS) {
             if (!plugins.contains(unmaintained)) {
@@ -247,9 +248,9 @@
      * if the plugins were last updated a long time ago.
      *
      * @param parent the parent window relative to which the confirmation dialog
      * is to be displayed
      * @return true if a plugin update should be run; false, otherwise
      */
-    public static boolean checkAndConfirmPluginUpdate(Window parent) {
+    public static boolean checkAndConfirmPluginUpdate(Component parent) {
         String message = null;
         String togglePreferenceKey = null;
@@ -355,8 +356,9 @@
      * Alerts the user if a plugin required by another plugin is missing
      *
+     * @param parent The parent Component used to display error popup
      * @param plugin the plugin
      * @param missingRequiredPlugin the missing required plugin
      */
-    private static void alertMissingRequiredPlugin(Window parent, String plugin, Set<String> missingRequiredPlugin) {
+    private static void alertMissingRequiredPlugin(Component parent, String plugin, Set<String> missingRequiredPlugin) {
         StringBuilder sb = new StringBuilder();
         sb.append("<html>");
@@ -380,5 +382,5 @@
     }
 
-    private static void alertJOSMUpdateRequired(Window parent, String plugin, int requiredVersion) {
+    private static void alertJOSMUpdateRequired(Component parent, String plugin, int requiredVersion) {
         HelpAwareOptionPane.showOptionDialog(
                 parent,
@@ -398,9 +400,10 @@
      * depends on should be missing.
      *
+     * @param parent The parent Component used to display error popup
      * @param plugins the collection of all loaded plugins
      * @param plugin the plugin for which preconditions are checked
      * @return true, if the preconditions are met; false otherwise
      */
-    public static boolean checkLoadPreconditions(Window parent, Collection<PluginInformation> plugins, PluginInformation plugin) {
+    public static boolean checkLoadPreconditions(Component parent, Collection<PluginInformation> plugins, PluginInformation plugin) {
 
         // make sure the plugin is compatible with the current JOSM version
@@ -411,4 +414,18 @@
             return false;
         }
+
+        return checkRequiredPluginsPreconditions(parent, plugins, plugin);
+    }
+
+    /**
+     * Checks if required plugins preconditions for loading the plugin <code>plugin</code> are met.
+     * No other plugins this plugin depends on should be missing.
+     *
+     * @param parent The parent Component used to display error popup
+     * @param plugins the collection of all loaded plugins
+     * @param plugin the plugin for which preconditions are checked
+     * @return true, if the preconditions are met; false otherwise
+     */
+    public static boolean checkRequiredPluginsPreconditions(Component parent, Collection<PluginInformation> plugins, PluginInformation plugin) {
 
         // make sure the dependencies to other plugins are not broken
@@ -469,5 +486,5 @@
      * @param pluginClassLoader the plugin class loader
      */
-    public static void loadPlugin(Window parent, PluginInformation plugin, ClassLoader pluginClassLoader) {
+    public static void loadPlugin(Component parent, PluginInformation plugin, ClassLoader pluginClassLoader) {
         String msg = tr("Could not load plugin {0}. Delete from preferences?", plugin.name);
         try {
@@ -499,5 +516,5 @@
      * @param monitor the progress monitor. Defaults to {@see NullProgressMonitor#INSTANCE} if null.
      */
-    public static void loadPlugins(Window parent,Collection<PluginInformation> plugins, ProgressMonitor monitor) {
+    public static void loadPlugins(Component parent,Collection<PluginInformation> plugins, ProgressMonitor monitor) {
         if (monitor == null) {
             monitor = NullProgressMonitor.INSTANCE;
@@ -548,5 +565,5 @@
      * @param monitor the progress monitor. Defaults to {@see NullProgressMonitor#INSTANCE} if null.
      */
-    public static void loadEarlyPlugins(Window parent, Collection<PluginInformation> plugins, ProgressMonitor monitor) {
+    public static void loadEarlyPlugins(Component parent, Collection<PluginInformation> plugins, ProgressMonitor monitor) {
         List<PluginInformation> earlyPlugins = new ArrayList<PluginInformation>(plugins.size());
         for (PluginInformation pi: plugins) {
@@ -565,5 +582,5 @@
      * @param monitor the progress monitor. Defaults to {@see NullProgressMonitor#INSTANCE} if null.
      */
-    public static void loadLatePlugins(Window parent, Collection<PluginInformation> plugins, ProgressMonitor monitor) {
+    public static void loadLatePlugins(Component parent, Collection<PluginInformation> plugins, ProgressMonitor monitor) {
         List<PluginInformation> latePlugins = new ArrayList<PluginInformation>(plugins.size());
         for (PluginInformation pi: plugins) {
@@ -610,5 +627,5 @@
     }
 
-    private static void alertMissingPluginInformation(Window parent, Collection<String> plugins) {
+    private static void alertMissingPluginInformation(Component parent, Collection<String> plugins) {
         StringBuilder sb = new StringBuilder();
         sb.append("<html>");
@@ -642,5 +659,5 @@
      * @return the set of plugins to load (as set of plugin names)
      */
-    public static List<PluginInformation> buildListOfPluginsToLoad(Window parent, ProgressMonitor monitor) {
+    public static List<PluginInformation> buildListOfPluginsToLoad(Component parent, ProgressMonitor monitor) {
         if (monitor == null) {
             monitor = NullProgressMonitor.INSTANCE;
@@ -675,5 +692,5 @@
     }
 
-    private static void alertFailedPluginUpdate(Window parent, Collection<PluginInformation> plugins) {
+    private static void alertFailedPluginUpdate(Component parent, Collection<PluginInformation> plugins) {
         StringBuffer sb = new StringBuffer();
         sb.append("<html>");
@@ -707,10 +724,10 @@
      * Updates the plugins in <code>plugins</code>.
      *
      * @param parent the parent window for message boxes
      * @param plugins the collection of plugins to update. Must not be null.
      * @param monitor the progress monitor. Defaults to {@see NullProgressMonitor#INSTANCE} if null.
      * @throws IllegalArgumentException thrown if plugins is null
      */
-    public static List<PluginInformation>  updatePlugins(Window parent,
+    public static List<PluginInformation>  updatePlugins(Component parent,
             List<PluginInformation> plugins, ProgressMonitor monitor)
             throws IllegalArgumentException{
@@ -797,5 +814,5 @@
      * @return true, if the plugin shall be disabled; false, otherwise
      */
-    public static boolean confirmDisablePlugin(Window parent, String reason, String name) {
+    public static boolean confirmDisablePlugin(Component parent, String reason, String name) {
         ButtonSpec [] options = new ButtonSpec[] {
                 new ButtonSpec(
@@ -247,9 +248,9 @@
      * if the plugins were last updated a long time ago.
      *
-     * @param parent the parent window relative to which the confirmation dialog
+     * @param parent the parent component relative to which the confirmation dialog
      * is to be displayed
      * @return true if a plugin update should be run; false, otherwise
@@ -707,10 +724,10 @@
      * Updates the plugins in <code>plugins</code>.
      *
-     * @param parent the parent window for message boxes
+     * @param parent the parent component for message boxes
      * @param plugins the collection of plugins to update. Must not be null.
      * @param monitor the progress monitor. Defaults to {@see NullProgressMonitor#INSTANCE} if null.